@@ -1,7 +1,7 @@
 package App::Ikachan;
 use strict;
 use warnings;
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 1;
 __END__
@@ -58,6 +58,11 @@ see L<Plack::Middleware::ReverseProxy>.
 
 irc post interval. for Excess Flood
 
+=item -R, --reconnect-interval
+
+interval of reconnect to irc server.
+exit application if interval == 0.
+
 =item -j, --no-post-with-join
 
 disable to irc message post with channel join
